@@ -1,15 +1,17 @@
 #include <R.h>
 #include <Rinternals.h>
 
-extern SEXP impl_annotateGene(SEXP arg_chrom,
-                          SEXP arg_pos,
-                          SEXP arg_ref,
-                          SEXP arg_alt);
-SEXP annotateGene(SEXP arg_chrom,
-              SEXP arg_pos,
-              SEXP arg_ref,
-              SEXP arg_alt) {
-  return impl_annotateGene(arg_chrom, arg_pos, arg_ref, arg_alt);
+extern SEXP impl_annotateGene(SEXP arg_param,
+                              SEXP arg_chrom,
+                              SEXP arg_pos,
+                              SEXP arg_ref,
+                              SEXP arg_alt);
+SEXP annotateGene(SEXP arg_param,
+                  SEXP arg_chrom,
+                  SEXP arg_pos,
+                  SEXP arg_ref,
+                  SEXP arg_alt) {
+  return impl_annotateGene(arg_param, arg_chrom, arg_pos, arg_ref, arg_alt);
 }
 
 extern SEXP impl_anno(SEXP arg_inFile,
